@@ -109,13 +109,7 @@ class DBConnect():
         find_data = self.mongo_collection.find(find_dict)
         records_filtered = find_data.count()
         if not records_filtered:
-            dict_data = {
-                'records_total': [],
-                'records_filtered': 0,
-                'query_result': 0,
-            }
-            abort(Response(dict_data, 204, {
-                  'Content-Type', 'text/plain; charset=utf-8'}))
+            abort(Response('请求数据不存在', 204, {'Content-Type', 'text/plain; charset=utf-8'}))
         if sort_list:
             find_data.sort(sort_list).limit(
                 page_size).skip(page_size*current)
